@@ -18,6 +18,15 @@ class Group(BaseModel):
     units: str
     amount_cents: int
 
+
+class ChargeFilterUsage(BaseModel):
+    invoice_display_name: Optional[str]
+    values: Dict[str, List[str]]
+    units: str
+    amount_cents: int
+    events_count: int
+
+
 class ChargeObject(BaseModel):
     lago_id: str
     charge_model: str
@@ -29,6 +38,7 @@ class GroupedUsage(BaseModel):
     units: float
     grouped_by: Dict[str, str]
     groups: List[Group]
+    filters: List[ChargeFilterUsage]
 
 class ChargeUsage(BaseModel):
     units: float
@@ -38,6 +48,7 @@ class ChargeUsage(BaseModel):
     charge: ChargeObject
     billable_metric: Metric
     groups: List[Group]
+    filters: List[ChargeFilterUsage]
     grouped_usage: Optional[List[GroupedUsage]]
 
 
